Learn R Programming

comradesOO (version 0.1.1)

foldComrades: foldComrades

Description

This methods folds an ensebl of structures for the whole RNA or chosen region of the RNA. See comradesDataSet for slot information.

Usage

foldComrades(
  cdsObject,
  rnaRefs,
  start,
  end,
  evCutoff = 1,
  ensembl = 50,
  constraintNumber = 20,
  shape = 0
)

Value

a comradesDataSet object

Arguments

cdsObject

comradesDataSet object created with comradesDataSet

rnaRefs

named List - a list with named elements that correspond to the .RNA of interest. The element of the list must be a fasta file that has been read with seqinr::read.fasta()

start

Start of segmnent to fold

end

End of segmnent to fold

evCutoff

Mininum number of read support for contraint to be included in folding

ensembl

Number of structures to Nake

constraintNumber

Number of constraints to add to each final fold

shape

shape reactivities (0 for no constraints)

Examples

Run this code
if (FALSE) {
cds = makeExampleComradesDataSet()

clusteredCds = clusterComrades(cds,
                cores = 1,
                stepCount = 1,
                clusterCutoff = 0)
                
trimmedClusters = trimClusters(clusteredCds = clusteredCds,
             trimFactor = 1, 
             clusterCutoff = 0)
             
              

fasta = paste(c(rep('A',25),
                rep('T',25),
                rep('A',10),
                rep('T',23)),collapse = "")

header = '>transcript1'


fastaFile = tempfile()
writeLines(paste(header,fasta,sep = "\n"),con = fastaFile)


rnaRefs = list()
rnaRefs[[rnas(cds)]] = read.fasta(fastaFile)
rnaRefs



foldedCds = foldComrades(trimmedClusters,
                         rnaRefs = rnaRefs,
                         start = 1,
                         end = 83,
                         shape = 0,
                         ensembl = 5,
                         constraintNumber  = 1,
                         evCutoff = 1)
foldedCds
}

Run the code above in your browser using DataLab