getClusterClusterShortRangeWhole: getClusterClusterShortRangeWhole
Description
Decides if a cluster is long or short range
then either grabs the whole sequence or the sequence of the two sides of the
interaction separately.
Usage
getClusterClusterShortRangeWhole(cluster, seq)
Value
The same table with an extra column
Arguments
- cluster
cluster positions
- seq
sequence of transcript