Learn R Programming

comradesOO (version 0.1.1)

swapHybs3: swapHybs3

Description

Swap the table to ensure that 3 prime most duplex side is ont he left of the table used to make one sides heatmaps and other reasons where having the left of the table coming after the right side is a problem. Different from swapHybs as it ensure that BOTH duplex sides originate from the RNA of interest.

Usage

swapHybs3(hybList, rna)

Value

A list of "swapped" hyb datas

Arguments

hybList

the original hybList created with readHybFiles or subsetHybList

rna

The rna of interest